==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/StepAreaSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalAnchoredCategorySeriesDescriptionMetadata } from "./HorizontalAnchoredCategorySeriesDescriptionMetadata";
import { StepAreaSeriesDescription } from "./StepAreaSeriesDescription";
/**
 * @hidden
 */
export let StepAreaSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class StepAreaSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (StepAreaSeriesDescriptionMetadata.a == null) {
                StepAreaSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                StepAreaSeriesDescriptionMetadata.c(StepAreaSeriesDescriptionMetadata.a);
            }
            if (a.k(StepAreaSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ab(StepAreaSeriesDescriptionMetadata.a);
        }
        static c(a) {
            HorizontalAnchoredCategorySeriesDescriptionMetadata.c(a);
        }
        static d(a) {
            StepAreaSeriesDescriptionMetadata.b(a);
            a.ad("StepAreaSeries", () => new StepAreaSeriesDescription());
            a.ac("StepAreaSeries", StepAreaSeriesDescriptionMetadata.a);
        }
    }
    StepAreaSeriesDescriptionMetadata.$t = markType(StepAreaSeriesDescriptionMetadata, 'StepAreaSeriesDescriptionMetadata');
    StepAreaSeriesDescriptionMetadata.a = null;
    return StepAreaSeriesDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/StepAreaSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalAnchoredCategorySeriesDescriptionMetadata } from "./HorizontalAnchoredCategorySeriesDescriptionMetadata";
import { StepAreaSeriesDescription } from "./StepAreaSeriesDescription";
/**
 * @hidden
 */
export let StepAreaSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class StepAreaSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (StepAreaSeriesDescriptionMetadata.a == null) {
                StepAreaSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                StepAreaSeriesDescriptionMetadata.c(StepAreaSeriesDescriptionMetadata.a);
            }
            if (a.k(StepAreaSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ac(StepAreaSeriesDescriptionMetadata.a);
        }
        static c(a) {
            HorizontalAnchoredCategorySeriesDescriptionMetadata.c(a);
        }
        static d(a) {
            StepAreaSeriesDescriptionMetadata.b(a);
            a.ae("StepAreaSeries", () => new StepAreaSeriesDescription());
            a.ad("StepAreaSeries", StepAreaSeriesDescriptionMetadata.a);
        }
    }
    StepAreaSeriesDescriptionMetadata.$t = markType(StepAreaSeriesDescriptionMetadata, 'StepAreaSeriesDescriptionMetadata');
    StepAreaSeriesDescriptionMetadata.a = null;
    return StepAreaSeriesDescriptionMetadata;
})();
